.. _resources-index:

*******************
 External Resources
*******************


=============================
 Books, Chapters and Articles
=============================

* `Mastering matplotlib
  <https://www.packtpub.com/big-data-and-business-intelligence/mastering-matplotlib>`_
  by Duncan M. McGreggor

* `Interactive Applications Using Matplotlib
  <https://www.packtpub.com/application-development/interactive-applications-using-matplotlib>`_
  by Benjamin Root

* `Matplotlib for Python Developers
  <https://www.packtpub.com/application-development/matplotlib-python-developers>`_
  by Sandro Tosi

* `Matplotlib chapter <http://www.aosabook.org/en/matplotlib.html>`_
  by John Hunter and Michael Droettboom in The Architecture of Open Source
  Applications

* `Ten Simple Rules for Better Figures
  <https://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1003833>`_
  by Nicolas P. Rougier, Michael Droettboom and Philip E. Bourne

* `Learning Scientific Programming with Python chapter 7
  <http://scipython.com/book/chapter-7-matplotlib/>`_
  by Christian Hill

=======
 Videos
=======

* `Plotting with matplotlib <https://www.youtube.com/watch?v=P7SVi0YTIuE>`_
  by Mike Müller

* `Introduction to NumPy and Matplotlib
  <https://www.youtube.com/watch?v=3Fp1zn5ao2M&feature=plcp>`_ by Eric Jones

* `Anatomy of Matplotlib
  <https://conference.scipy.org/scipy2013/tutorial_detail.php?id=103>`_
  by Benjamin Root

* `Data Visualization Basics with Python (O'Reilly)
  <http://shop.oreilly.com/product/0636920046592.do>`_
  by Randal S. Olson

==========
 Tutorials
==========

* `Matplotlib tutorial <http://www.labri.fr/perso/nrougier/teaching/matplotlib/>`_
  by Nicolas P. Rougier

* `Anatomy of Matplotlib - IPython Notebooks
  <https://github.com/WeatherGod/AnatomyOfMatplotlib>`_
  by Benjamin Root
